import fs from 'fs'
import path from 'path'
import { fileURLToPath, URL } from 'url'

import { defineConfig } from 'vite'
import vue from '@vitejs/plugin-vue'
import checker from 'vite-plugin-checker'
import AutoImport from 'unplugin-auto-import/vite'

export default defineConfig(({ mode }) => {
  return {
    base: mode === 'prod' ? 'https://webapp-pub.ezijing.com/website/prod/vst-saas/' : '/',
    plugins: [
      checker({ vueTsc: true, eslint: { lintCommand: 'eslint "./src/**/*.{vue,js,jsx,ts,tsx}"' } }),
      vue(),
      AutoImport({
        imports: ['vue', 'vue/macros', 'vue-router', '@vueuse/core'],
        dts: true,
        eslintrc: { enabled: true }
      })
    ],
   
    server: {
      open: true,
      host: 'dev.ezijing.com',
      https: {
        key: fs.readFileSync(path.join(__dirname, './https/dev.ezijing.com.key')),
        cert: fs.readFileSync(path.join(__dirname, './https/dev.ezijing.com.pem'))
      }
    },
    resolve: {
      alias: {
        '@': fileURLToPath(new URL('./src', import.meta.url))
      }
    }
  }
})
